import React from 'react';
import PropTypes from 'prop-types';

import Paper from '@material-ui/core/Paper';
import Image from '../Image/Image';
import TextLabel from '../TextLabel/TextLabel';


import getStyles from './LauncherItem.styles';

/**
 * A listing of workbench action launchers
 */
const LauncherItem = (props) => {
    const {
        icon,
        text,
        onClick,
        contextStyles,
        testID,
    } = props;

    const styles = getStyles(contextStyles);

    // Generate container props
    const containerProps = {
        className: 'c-launcher-item__container',
        style: styles.container,
    };
    if (onClick) { containerProps.onClick = onClick; }
    if (testID) { containerProps['data-test-id'] = `${testID}__launcher-item__container`; }

    // Generate icon props
    const iconProps = {
        className: 'c-launcher-item__image',
        contextStyles: {
            container: styles.iconContainer,
            image: styles.icon,
        },
        imageSrc: icon,
    };
    if (testID) { iconProps.testID = `${testID}__launcher-item__image`; }

    // Generate text props
    const textProps = {
        className: 'c-launcher-item__text',
        contextStyles: {
            container: styles.textContainer,
            text: styles.text,
        },
    };
    if (testID) { textProps.testID = `${testID}__launcher-item__text`; }

    return (
        <Paper { ...containerProps }>
            <Image { ...iconProps } />
            <TextLabel { ...textProps }>
                { text }
            </TextLabel>
        </Paper>
    );
};

LauncherItem.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styling for the main container */
        container: PropTypes.object,

        /** Styling for the icon */
        icon: PropTypes.object,

        /** Styling for the text */
        text: PropTypes.object,
    }),

    /** Launcher icon/image */
    icon: PropTypes.string.isRequired,

    /** Called on launcher click */
    onClick: PropTypes.func,

    /** Id used for testing */
    testID: PropTypes.string,

    /** Launcher text */
    text: PropTypes.string.isRequired,
};

LauncherItem.defaultProps = {
    contextStyles: {},
};

export default LauncherItem;
