import React from 'react';
import PropTypes from 'prop-types';

class BooleanFilter extends React.Component {
    render() {
        const {
            field,
            width,
            textBoxes,
            nameStyle,
            inputStyles,
            placeholder,
        } = this.props;

        return (
            <div style={ {
                width: width,
                ...nameStyle,
            } }>
                {
                    placeholder
                }
                <div style={ inputStyles }>
                    <input
                        onChange={ this.handleChange.bind(this) }
                        type="radio"
                        name="selection"
                        checked={ textBoxes[field] }
                        value="yes" />
                    Yes
                </div>
                <div style={ {
                    ...inputStyles,
                    alignContent: 'center',
                } }>
                    <input
                        onChange={ this.handleChange.bind(this) }
                        type="radio"
                        name="selection"
                        checked={ !textBoxes[field] && typeof textBoxes[field] === 'boolean' }
                        value="no" />
                    No
                </div>
            </div>
        );
    }

    /**
     * Handles changes on boolean filter and pass on the value.
     */
    handleChange = (e) => {
        e.persist();
        const {
            field,
            onValueChanged,
        } = this.props;

        let booleanValue = null;

        if (e.target.value === 'yes') {
            booleanValue = true;
        }
        else if (e.target.value === 'no') {
            booleanValue = false;
        }

        const textBoxes = {
            [field]: booleanValue,
        };

        if (onValueChanged) {
            onValueChanged(field, textBoxes);
        }
    }
};

BooleanFilter.propTypes = {
    /** Width of corresponding column */
    width: PropTypes.string,

    /** Unique identifier for the column */
    field: PropTypes.string,

    /** HeaderName of the column */
    placeholder: PropTypes.string,

    /** Object containing filter text for filter components */
    textBoxes: PropTypes.object,

    /** Handler to pass on changed/ updated value to parent */
    onValueChanged: PropTypes.func,

    /** Style object */
    nameStyle: PropTypes.object,

    /** Style object */
    inputStyles: PropTypes.object,
};

export default BooleanFilter;