import React, { forwardRef } from 'react';
import PropTypes from 'prop-types';
import MUIMenuItem from '@material-ui/core/MenuItem';

import { makeStyles } from '@material-ui/core/styles';
import getStyles from './MenuItem.styles';

// eslint-disable-next-line react/display-name
const MenuItem = forwardRef((props, ref) => {
    const {
        contextStyles,
        onClick,
        selected,
        testID,
        text,
        ...rest
    } = props;

    // Override core styles with context styles, separating MUI styles
    const muiStyles = getStyles(contextStyles);

    // Create dynamic class names and injected DOM styles for MUI component
    // * makeStyles returns a function
    const styles = makeStyles(muiStyles)();

    // Generate container props
    const containerProps = {
        classes: {
            root: styles.container, // MUI styles
            selected: styles.selected, // MUI styles
        },
        className: 'c-menu-item__container',
        selected,
        onClick,
        ...rest,
    };
    if (testID) { containerProps['data-test-id'] = `${testID}__menu-item__container`; }

    return (
        <MUIMenuItem
            ref={ ref }
            { ...containerProps }>
            { text }
        </MUIMenuItem>
    );
});

MenuItem.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styling for the item */
        container: PropTypes.object,

        /** Styling for the selected item */
        selected: PropTypes.object,
    }),

    /**  */
    onClick: PropTypes.func.isRequired,

    /** Enables selected styling */
    selected: PropTypes.bool,

    /** Id used for testing */
    testID: PropTypes.string,

    /** Menu item text */
    text: PropTypes.string.isRequired,
};

MenuItem.defaultProps = {
    contextStyles: {},
};

export default MenuItem;
